#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_LOG10_PI_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_LOG10_PI_HPP_INCLUDED

#include <boost/simd/constant/include/constants/log10_pi.hpp>

#endif
